Indiana Courts > Appellate Opinions
Keywords: Court, Indiana, Information, Judiciary, Courts, State, Help

INFORMATION FOR... PUBLIC JUDGES CLERKS EDUCATORS PRESS ATTORNEYS COURT STAFF STUDENTS Courts IN.gov
home > law library > appellate opinions |
Indiana Appellate Opinions - Appeals
These files are in PDF format. To view a PDF file you will need Adobe Acrobat Reader which is available free of charge at Adobe's Website. |
Brian S. Hartman v. State of Indiana (NFP) 68A05-1311-CR-579 68C01-1002-MR-17 09/03/14 Town of Cedar Lake v. Review Board of the Indiana Department of Workforce Development and Mary J Dickson (NFP) 93A02-1402-EX-72 13-R-04534 09/03/14 Brian House v. State of Indiana (NFP) 48A04-1402-CR-78 48C01-1306-FD-1203 09/03/14 Anthony Johnson v. State of Indiana (NFP) 49A04-1312-CR-612 49F08-1309-CM-60680 09/03/14 Papa Ndiaye v. Review Board of the Indiana Department of Workforce Development and Federal Mogul Corp. (NFP) 93A02-1402-EX-124 14-R-00225 09/03/14 Mobile Home Management Indiana, LLC v. Avon Village MHP, LLC, State of Indiana Bureau of Motor Vehicles, Treasurer of Hendricks County Indiana 32A04-1401-MI-6 32D05-1308-MI-171 09/03/14 Tarik Fields v. State of Indiana (NFP) 49A02-1401-CR-27 49F08-1203-FD-18112 09/03/14 Raveon Harrell v. State of Indiana (NFP) 71A03-1310-PC-412 71D01-0906-PC-27 09/03/14 B.J. v. State of Indiana (NFP) 28A01-1403-JV-113 28C01-1402-JD-4 09/03/14 Samantha Lee v. State of Indiana (NFP) 31A01-1401-CR-4 31D01-1112-FD-988 09/03/14 Charles W. Turner v. Montague M. Oliver, Jr. (NFP) 48A02-1402-CT-110 48C01-1107-CT-113, 48C02-1107-CT-198 09/03/14 Kristen Shane Lester v. State of Indiana (NFP) 47A01-1402-CR-95 47D01-1011-FD-1378, 47D01-1012-FD-1408, 47D01-1101-FD-60 09/03/14 J.J. v. State of Indiana (NFP) 49A04-1401-JV-18 49D09-1310-JD-3028 09/03/14 Brandon J. Lunkin v. State of Indiana (NFP) 20A03-1401-CR-46 20C01-1301-FB-4 09/03/14 David Hooker v. State of Indiana (NFP) 82A01-1311-CR-523 82C01-0109-CF-816 09/03/14 Mariea L. Best v. Russell C. Best (NFP) 06A04-1403-DR-124 06C01-0209-DR-381 09/03/14 Davetta Davidson v. State of Indiana (NFP) 71A03-1401-CR-4 71D01-1206-CM-3563 09/03/14 Timothy McSchooler v. State of Indiana 32A01-1401-CR-13 32D04-1310-FD-1092 09/03/14 Cameron Wood v. State of Indiana (NFP) 34A02-1311-CR-953 34D02-1212-FB-332 09/03/14 Jared W. Baehl v. State of Indiana (NFP) 87A01-1311-CR-515 87D02-1210-FD-390 09/03/14 In Re the Matter of Z.G., J.C., and H.H.: Children Alleged to Be Children in Need of Services S.H. (Mother) & K.G. (Father of Z.G.) v. The Indiana Department of Child Services (NFP) 52A02-1403-JC-160 52C01-1309-JC-81, 52C01-1309-JC-82, and 52C01-1309-JC-83 09/02/14 David Hooker v. Shari Hooker 82A04-1311-DR-592 82D04-0911-DR-987 08/29/14 Thomas D. Dillman v. State of Indiana 53A05-1306-CR-274 53C05-0509-CM-3054 08/29/14 Julianna Eagan, formerly Julianna Paciorkowski v. Christopher Paciorkowski (NFP) 20A03-1312-DR-493 20D02-0502-DR-98 08/29/14 Johnnylee Sims v. State of Indiana (NFP) 71A05-1403-CR-98 71D03-1207-FC-169 08/29/14 John Palatas v. State of Indiana (NFP) 89A05-1403-CR-134 89C01-1304-FA-12, 89C01-1312-FA-37 08/29/14 Calvin Turner v. State of Indiana (NFP) 48A04-1403-CR-96 48C01-1207-FD-1280 08/29/14 Jeffrey Elkins v. State of Indiana (NFP) 28A01-1404-CR-166 28C01-1305-FD-86 08/29/14 Julius J. Rice v. State of Indiana (NFP) 49A05-1311-CR-552 49G02-1212-FB-82166 08/29/14 Ronald DeWayne Thompson v. State of Indiana 45A03-1401-CR-8 45G03-1301-FA-2 08/29/14 C.H. v. State of Indiana 49A02-1310-JV-904 49D09-1306-JD-1818 08/29/14 Herman Gehl, II v. State of Indiana (NFP) 59A01-1401-PC-12 59D01-1307-PC-493 08/29/14 Charles E. Justise, Sr. v. Indiana Department of Correction (NFP) 49A05-1309-PL-462 49D02-1107-PL-25903 08/29/14 Colby R. McKnelly v. State of Indiana (NFP) 30A05-1307-CR-378 30C01-1212-MR-1947 08/29/14 Bruce Johnson-El v. State of Indiana (NFP) 09A02-1302-PC-270 09D02-1102-PC-1 08/29/14 Kalan Murphy v. State of Indiana (NFP) 71A03-1311-CR-433 71D03-1305-FC-108 08/29/14 Quenton D. Davis v. State of Indiana (NFP) 02A05-1401-CR-28 02D05-1308-FD-921 08/29/14
Last modified on Wednesday, September, 03, 2014